# LinuxBIOS build script

ifeq ($(LINUXBIOS_VENDOR),)
LINUXBIOS_VENDOR=tyan
endif
ifeq ($(LINUXBIOS_BOARD),)
LINUXBIOS_BOARD=kernel2892
endif
ifeq ($(LINUXBIOS_CONFIG),)
LINUXBIOS_CONFIG=Config.lb
endif
ifeq ($(LINUXBIOS_TDIR),)
LINUXBIOS_TDIR=s2892
endif
ifeq ($(LINUXBIOS_VER),)
LINUXBIOS_VER=2376
endif

LINUXBIOS_PATCHES =  

ifeq ($(LINUXBIOS_ENABLE_LZMA),y)
#LINUXBIOS_PATCHES += $(PACKAGE_DIR)/linuxbios/lzma-config.patch
endif

ifeq ($(LINUXBIOS_CAS25),y)
#LINUXBIOS_PATCHES += $(PACKAGE_DIR)/linuxbios/CL2.5.patch
endif

LINUXBIOS_SOURCE_DIR=LinuxBIOSv2
LINUXBIOS_SVN=svn://openbios.org/repos/trunk/LinuxBIOSv2
LINUXBIOS_DIR=$(BUILD_DIR)/linuxbios
LINUXBIOS_SRC_DIR=$(LINUXBIOS_DIR)/$(LINUXBIOS_SOURCE_DIR)
LINUXBIOS_TARGET_DIR=$(LINUXBIOS_SRC_DIR)/targets/
LINUXBIOS_TARGET_NAME=$(LINUXBIOS_VENDOR)/$(LINUXBIOS_BOARD)
LINUXBIOS_CONFIG_NAME=$(LINUXBIOS_TARGET_NAME)/$(LINUXBIOS_CONFIG)
LINUXBIOS_BUILD_DIR=$(LINUXBIOS_TARGET_DIR)/$(LINUXBIOS_TARGET_NAME)/$(LINUXBIOS_TDIR)

LINUXBIOS_TARBALL=linuxbios-svn-$(LINUXBIOS_VER).tar.gz

LINUXBIOS_STAMP_DIR=$(LINUXBIOS_DIR)/stamps
LINUXBIOS_LOG_DIR=$(LINUXBIOS_DIR)/logs

ifeq ($(VERBOSE),y)
LINUXBIOS_FETCH_LOG=/dev/stdout
LINUXBIOS_CONFIG_LOG=/dev/stdout
LINUXBIOS_BUILD_LOG=/dev/stdout
LINUXBIOS_INSTALL_LOG=/dev/stdout
NRV2B_BUILD_LOG=/dev/stdout
else
LINUXBIOS_FETCH_LOG=$(LINUXBIOS_LOG_DIR)/fetch.log
LINUXBIOS_BUILD_LOG=$(LINUXBIOS_LOG_DIR)/build.log
LINUXBIOS_CONFIG_LOG=$(LINUXBIOS_LOG_DIR)/config.log
LINUXBIOS_INSTALL_LOG=$(LINUXBIOS_LOG_DIR)/install.log
NRV2B_BUILD_LOG=$(LINUXBIOS_LOG_DIR)/nrv2b.build.log
endif

$(LINUXBIOS_STAMP_DIR)/.pull_svn_$(LINUXBIOS_VER): 
	 echo "Checking Linuxbios repository..."
	$(BIN_DIR)/fetchsvn.sh $(LINUXBIOS_SVN) $(SOURCE_DIR)/$(LINUXBIOS_SOURCE_DIR) \
	$(LINUXBIOS_VER) > $(LINUXBIOS_FETCH_LOG) 2>&1
	 touch $@

# fix me sooner or later!
/tmp/olpcpayload.elf: $(PAYLOAD_TARGET)
	@ cp $< $@

$(SOURCE_DIR)/$(LINUXBIOS_TARBALL): $(LINUXBIOS_STAMP_DIR)/.pull_svn_$(LINUXBIOS_VER)
	@ echo "Creating the LinuxBIOS tarball..."
	@ rm -f $(LINUXBIOS_TARBALL)
	@ tar -C $(SOURCE_DIR) -zcf $(SOURCE_DIR)/$(LINUXBIOS_TARBALL) \
	$(LINUXBIOS_SOURCE_DIR)

$(LINUXBIOS_STAMP_DIR)/.unpacked: $(SOURCE_DIR)/$(LINUXBIOS_TARBALL)
	@ echo "Unpacking LinuxBIOS..."
	@ tar -C $(LINUXBIOS_DIR) -zxf $(SOURCE_DIR)/$(LINUXBIOS_TARBALL)
	@ touch $@	

$(LINUXBIOS_STAMP_DIR)/.patched: $(LINUXBIOS_STAMP_DIR)/.unpacked
	@ echo "Patching LinuxBIOS..."
	@ $(BIN_DIR)/doquilt.sh $(LINUXBIOS_SRC_DIR) $(LINUXBIOS_PATCHES)
	@ touch $@

$(LINUXBIOS_STAMP_DIR)/.configured: $(LINUXBIOS_STAMP_DIR)/.patched
	@ echo "Building target config file..."
	@( cd $(LINUXBIOS_TARGET_DIR); \
	./buildtarget $(LINUXBIOS_CONFIG_NAME) > $(LINUXBIOS_CONFIG_LOG) 2>&1)
	@ touch $@

$(LINUXBIOS_BUILD_DIR)/linuxbios.rom:  $(LINUXBIOS_STAMP_DIR)/.configured /tmp/olpcpayload.elf
	@ echo "Building linuxbios..."
	@ make -C $(LINUXBIOS_BUILD_DIR) > $(LINUXBIOS_BUILD_LOG) 2>&1

$(OUTPUT_DIR)/linuxbios.rom:  $(LINUXBIOS_BUILD_DIR)/linuxbios.rom
	@ echo "Making the ROM..."
	@ cat $(PACKAGE_DIR)/bin/ec.bin $(PACKAGE_DIR)/bin/olpc_vsa.64k.bin \
	$(LINUXBIOS_BUILD_DIR)/linuxbios.rom > $@
	@ md5sum $@ | cut -d ' ' -f 1 > $(OUTPUT_DIR)/linuxbios.rom.md5

$(LINUXBIOS_SRC_DIR)/util/nrv2b/nrv2b: $(LINUXBIOS_STAMP_DIR)/.patched
	@ echo "Building nrv2b..."
	@ make -C $(LINUXBIOS_SRC_DIR)/util/nrv2b CFLAGS="$(HOST_CFLAGS)" \
	LDFLAGS=$(HOST_LDFLAGS) > $(NRV2B_BUILD_LOG) 2>&1

$(STAGING_DIR)/bin/nrv2b: $(LINUXBIOS_SRC_DIR)/util/nrv2b/nrv2b
	@ install -d $(STAGING_DIR)/bin
	@ install -m 0755 $< $@

$(LINUXBIOS_STAMP_DIR) $(LINUXBIOS_LOG_DIR):
	@ mkdir -p $@

linuxbios: $(LINUXBIOS_STAMP_DIR) $(LINUXBIOS_LOG_DIR) $(OUTPUT_DIR)/linuxbios.rom

nrv2b: $(LINUXBIOS_STAMP_DIR) $(LINUXBIOS_LOG_DIR) $(STAGING_DIR)/bin/nrv2b

linuxbios-clean:
	@ echo "Cleaning linuxbios..."
	@ $(MAKE) -C $(LINUXBIOS_BUILD_DIR) clean > /dev/null 2>&1

linuxbios-distclean:
	@ rm -rf $(LINUXBIOS_DIR)/*

linuxbios-bom:
	@ echo "Package: linuxbios"
	@ echo "Source:  $(LINUXBIOS_SVN)"
	@ echo "Revison: $(LINUXBIOS_VER)"
	@ echo "Tarball: linuxbios-svn-$(LINUXBIOS_VER).tar.gz"
	@ echo ""

